@@ -163,7 +163,6 @@ public:
     }
     
     void buildVolumeElements() {
-        int dimension = 0;
         if(_volumeElementConfigurationMap.size() == 0) {
             return;
         }
@@ -193,8 +192,10 @@ public:
     }
     void buildVolumeElementTree(Progress* pProgress) {
         _pVpVolumeElementConfigurations = new VpVolumeElementConfigurations<bool>(_volumeElements);
-        delete pProgress;
-        pProgress = new Progress(_pVpVolumeElementConfigurations->getSize());
+        if(pProgress != 0) {
+            pProgress->reset(_pVpVolumeElementConfigurations->getSize());
+        }
+
         delete _pVpTree;
         _pVpTree = new VpTree<bool>();
         _pVpTree->build(_pVpVolumeElementConfigurations, new L1Distance<bool>(), pProgress);
@@ -220,11 +221,11 @@ public:
         if(boundary && !_volumeElements[i].isBoundaryElement()) {
             return;
         }
-            
+
         vector<VpElement> adjacentVolumeElements = gedAdjacentVolumeElements(i, kDistances, k);
         VpElementCompare vpElementCompare;
         sort(adjacentVolumeElements.begin(), adjacentVolumeElements.end(), vpElementCompare);
-            
+ 
         vector<VpElement> positiveAdjacentVolumeElements = getSignedAdjacentVolumeElements(adjacentVolumeElements, true);
         vector<VpElement> negativeAdjacentVolumeElements = getSignedAdjacentVolumeElements(adjacentVolumeElements, false);
         if(positiveAdjacentVolumeElements.size() > _volumeElements[i].getPositiveAdjacentVolumeElements().size()) {
@@ -244,22 +245,25 @@ public:
         }
     }
     void buildVolumeElementGraphIterative(int kDistances, int k, int iterations, bool boundary = false, Progress* pProgress = 0) {
-        delete pProgress;
-        pProgress = new Progress(iterations * _volumeElements.size());
-        
-        int kNearestNeighbours = kDistances;
+        if(pProgress != 0) {
+            pProgress->reset(iterations * _volumeElements.size());
+        }
+
+        int kNearestNeighbors = kDistances;
         for(int i = 1; i <= iterations; i++) {
-            buildVolumeElementGraph(kNearestNeighbours, k, boundary, pProgress);
-            kNearestNeighbours = kNearestNeighbours * 2;
+            buildVolumeElementGraph(kNearestNeighbors, k, boundary, pProgress);
+            kNearestNeighbors = kNearestNeighbors * 2;
             
-            pProgress->setOffset(i * _volumeElements.size());
+            if(pProgress != 0) {
+                pProgress->setOffset(i * _volumeElements.size());
+            }
         }
     }
     void buildVolumeElementGraphMetricSubspaceElement(int kDistances, int k, int maxSize, bool boundary = false) {
         buildMetricSubspaceElements();
         for(int i = 0; i < (int)getMetricSubspaceElements().size(); i++) {
-            if(getMetricSubspaceElements()[i].getVolumeElementIndices().size() <= maxSize) {
-                for(int j = 0; j < getMetricSubspaceElements()[i].getVolumeElementIndices().size(); j++) {
+            if((int)(getMetricSubspaceElements()[i].getVolumeElementIndices().size()) <= maxSize) {
+                for(int j = 0; j < (int)(getMetricSubspaceElements()[i].getVolumeElementIndices().size()); j++) {
                     int index = getMetricSubspaceElements()[i].getVolumeElementIndices()[j];
                     buildVolumeElementGraph(index, kDistances, k, boundary);
                 }
@@ -285,34 +289,34 @@ public:
       return numberOfMetricSubspaces;
     }
     vector<VpElement> gedAdjacentVolumeElements(int index, int kDistances, int k) {
-        vector<VpElement> nearestNeighbours;
+        vector<VpElement> nearestNeighbors;
         
         vector<bool>& target = _volumeElements[index].getVolumeElementConfiguration();
-        _pVpTree->search(target, kDistances, k, nearestNeighbours);
+        _pVpTree->search(target, kDistances, k, nearestNeighbors);
         vector<VpElement> adjacentElements;
         
-        for(int i = 0; i < (int)nearestNeighbours.size(); i++) {
-            if(nearestNeighbours[i].getDistance() == 0) {
+        for(int i = 0; i < (int)nearestNeighbors.size(); i++) {
+            if(nearestNeighbors[i].getDistance() == 0) {
                 continue;
             }
-            if(nearestNeighbours[i].getDistance() == 1) {
-                adjacentElements.push_back(nearestNeighbours[i]);
+            if(nearestNeighbors[i].getDistance() == 1) {
+                adjacentElements.push_back(nearestNeighbors[i]);
                 continue;
             }
             
-            vector<bool>& a = _volumeElements[nearestNeighbours[i].getIndex()].getVolumeElementConfiguration();
-            float da = nearestNeighbours[i].getDistance();
+            vector<bool>& a = _volumeElements[nearestNeighbors[i].getIndex()].getVolumeElementConfiguration();
+            float da = nearestNeighbors[i].getDistance();
             bool adjacent = true;
             for(int j = 0; j < i; j++) {
-                if(nearestNeighbours[j].getDistance() == 0) {
+                if(nearestNeighbors[j].getDistance() == 0) {
                     continue;
                 }
                 if(j == i) {
                     continue;
                 }
-                vector<bool>& b = _volumeElements[nearestNeighbours[j].getIndex()].getVolumeElementConfiguration();
+                vector<bool>& b = _volumeElements[nearestNeighbors[j].getIndex()].getVolumeElementConfiguration();
                 
-                float db = nearestNeighbours[j].getDistance();
+                float db = nearestNeighbors[j].getDistance();
                 if(da == db) {
                     continue;
                 }
@@ -323,7 +327,7 @@ public:
                 }
             }
             if(adjacent) {
-                adjacentElements.push_back(nearestNeighbours[i]);
+                adjacentElements.push_back(nearestNeighbors[i]);
             }
             
         }
@@ -465,7 +469,7 @@ public:
     set<int> getAdjacentvolumeElementSubspaceElements(int metricSubspaceElementIndex) {
         set<int> adjacentVolumeElementSubspaceElementIndices;
         vector<int>& volumeElementIndices = _metricSubspaceElements[metricSubspaceElementIndex].getVolumeElementIndices();
-        for(int j = 0; j < volumeElementIndices.size(); j++) {
+        for(int j = 0; j < (int)volumeElementIndices.size(); j++) {
             int volumeElementIndex = volumeElementIndices[j];
             if(_volumeElements[volumeElementIndex].isBoundaryElement()) {
                 if(_volumeElements[volumeElementIndex].getPositive()) {
